'use client';
import React, { useState } from 'react';
import { styled, useTheme } from '@mui/material/styles';
import Box from '@mui/material/Box';
import Drawer from '@mui/material/Drawer';
import MuiAppBar from '@mui/material/AppBar';
import Toolbar from '@mui/material/Toolbar';
import CssBaseline from '@mui/material/CssBaseline';
import Typography from '@mui/material/Typography';
import Divider from '@mui/material/Divider';
import IconButton from '@mui/material/IconButton';
import MenuIcon from '@mui/icons-material/Menu';
import ChevronLeftIcon from '@mui/icons-material/ChevronLeft';
import ChevronRightIcon from '@mui/icons-material/ChevronRight';
import List from '@mui/material/List';
import ListItem from '@mui/material/ListItem';
import ListItemButton from '@mui/material/ListItemButton';
import ListItemIcon from '@mui/material/ListItemIcon';
import ListItemText from '@mui/material/ListItemText';
import InboxIcon from '@mui/icons-material/MoveToInbox';
import MailIcon from '@mui/icons-material/Mail';
import Main from '@/components/Main';
import Image from 'next/image';
import icon from '@/public/assets/images/icon-main.svg'
import icon2 from '@/public/assets/images/icon-2.svg'
import icon3 from '@/public/assets/images/icon-3.svg'
import icon4 from '@/public/assets/images/icon-4.svg'
import icon5 from '@/public/assets/images/icon-5.svg'
import avatar1 from '@/public/assets/images/avatar-1.png'
import Link from 'next/link';
import { FiSearch } from "react-icons/fi";
import { IoIosArrowDown } from "react-icons/io";
import { usePathname, useRouter } from 'next/navigation';
import Menu from '@mui/material/Menu';
import AccountCircle from '@mui/icons-material/AccountCircle';
import MenuItem from '@mui/material/MenuItem';
import { FaUsers } from "react-icons/fa";
import { getCookie, deleteCookie } from 'cookies-next';
import { FaEarthAfrica } from "react-icons/fa6";
import { BsListStars } from "react-icons/bs";
import { RiAdminFill } from "react-icons/ri";
import { PiUsersFourFill } from "react-icons/pi";

const drawerWidth = 240;

const AppBar = styled(MuiAppBar, {
  shouldForwardProp: (prop) => prop !== 'open',
})(({ theme, open }) => ({
  transition: theme.transitions.create(['margin', 'width'], {
    easing: theme.transitions.easing.sharp,
    duration: theme.transitions.duration.leavingScreen,
  }),
  ...(open && {
    width: `calc(100% - ${drawerWidth}px)`,
    transition: theme.transitions.create(['margin', 'width'], {
      easing: theme.transitions.easing.easeOut,
      duration: theme.transitions.duration.enteringScreen,
    }),
    marginRight: drawerWidth,
  }),
}));

const DrawerHeader = styled('div')(({ theme }) => ({
  display: 'flex',
  alignItems: 'center',
  padding: theme.spacing(0, 1),
  ...theme.mixins.toolbar,
  justifyContent: 'flex-start',
}));

const Sidebar = ({ children }) => {
  const theme = useTheme();
  const path = usePathname();
  const [open, setOpen] = React.useState(false);
  const [anchorEl, setAnchorEl] = React.useState(null);
  const [isAuthenticated, setIsAuthenticated] = React.useState(false);
  const authenticated = getCookie('currentUser') === 'true';
  const router = useRouter();
  React.useEffect(() => {
    setIsAuthenticated(authenticated);
  }, [authenticated]);
  if (!isAuthenticated) {
    return null;
  }
  const handleDrawerOpen = () => {
    setOpen(true);
  };

  const handleDrawerClose = () => {
    setOpen(false);
  };
  const handleMenu = (event) => {
    setAnchorEl(event.currentTarget);
  };

  const handleClose = () => {
    setAnchorEl(null);
  };
  const handleLogout = () => {
    setAnchorEl(null);
    deleteCookie('currentUser');
    deleteCookie('authToken');
    router.push('/');
  }

  return (
    <Box sx={{ display: 'flex', }}>
      <CssBaseline />
      <AppBar position="fixed" open={open} sx={{
        backgroundColor: '#FFFFFF',
        color: '#000',
        padding: 1,
      }}>
        <Toolbar>
          <IconButton
            color="inherit"
            aria-label="open drawer"
            edge="end"
            onClick={handleDrawerOpen}
            sx={{ ...(open && { display: 'none' }) }}
          >
            <MenuIcon sx={{
              color: '#000'
            }} />
          </IconButton>
          <div className="d-flex align-items-center justify-content-end flex-grow-1 me-5">
            <div>
              <IconButton
                size="large"
                aria-label="account of current user"
                aria-controls="menu-appbar"
                aria-haspopup="true"
                onClick={handleMenu}
                color="inherit"
              >
                <AccountCircle />
              </IconButton>
              <Menu
                id="menu-appbar"
                anchorEl={anchorEl}
                anchorOrigin={{
                  vertical: 'top',
                  horizontal: 'right',
                }}
                keepMounted
                transformOrigin={{
                  vertical: 'top',
                  horizontal: 'right',
                }}
                sx={{
                  '& .MuiMenu-paper': {
                    backgroundColor: '#F15B26',
                    color: '#fff',
                    marginTop: 5
                  }
                }}
                open={Boolean(anchorEl)}
                onClose={handleClose}
              >
                <MenuItem onClick={handleClose} >
                  <Link href={'/dashboard/profile'} className='nav-link d-flex align-items-center gap-3 w-100'>
                    <span className='w-100 d-flex justify-content-end'>
                      الملف الشخصي
                    </span>
                  </Link>
                </MenuItem>
                <MenuItem onClick={handleLogout}>
                  <span className='w-100 d-flex justify-content-end'>
                    تسجيل الخروج
                  </span>
                </MenuItem>
              </Menu>
            </div>
          </div>
        </Toolbar>
      </AppBar>
      <Main open={open}>{children}</Main>
      <Drawer
        sx={{
          width: 0,
          flexShrink: 0,
          '& .MuiDrawer-paper': {
            width: drawerWidth,
            padding: 1,
            backgroundColor: '#161616',
            color: '#fff'
          },
        }}
        variant="persistent"
        anchor="right"
        open={open}
      >
        <DrawerHeader sx={{ justifyContent: 'space-between', padding: 1, marginBottom: 3 }}>
          <Image src={icon} width={50} height={50} alt='logo' />
          <IconButton onClick={handleDrawerClose}>
            <Image width={30} height={30} alt='close' src={icon2} />
          </IconButton>
        </DrawerHeader>
        <Divider />
        <List>
          <ListItem>
            <Link href={'/dashboard/subscribers'} className='nav-link d-flex align-items-center gap-3 w-100'>
              <FaUsers color='#fff' fontSize={20} />
              <span>
                المشتركين
              </span>
            </Link>
          </ListItem>
          <ListItem>
            <Link href={'/dashboard/country'} className='nav-link d-flex align-items-center gap-3 w-100'>
              <FaEarthAfrica color='#fff' fontSize={20} />
              <span>
                الدول
              </span>
            </Link>
          </ListItem>
          <ListItem>
            <Link href={'/dashboard/feature'} className='nav-link d-flex align-items-center gap-3 w-100'>
              <BsListStars color='#fff' fontSize={20} />
              <span>
                الميزات
              </span>
            </Link>
          </ListItem>
          <ListItem>
            <Link href={'/dashboard/admin'} className='nav-link d-flex align-items-center gap-3 w-100'>
              <RiAdminFill color='#fff' fontSize={20} />
              <span>
                المشرفين
              </span>
            </Link>
          </ListItem>
          <ListItem>
            <Link href={'/dashboard/users'} className='nav-link d-flex align-items-center gap-3 w-100'>
              <PiUsersFourFill color='#fff' fontSize={20} />
              <span>
                المستخدمين
              </span>
            </Link>
          </ListItem>
        </List>
        <Divider />
      </Drawer>
    </Box>
  );
};

export default Sidebar;
