import axios from 'axios';
import { getCookie } from 'cookies-next';
import Swal from 'sweetalert2';
const API = axios.create({
    baseURL: 'https://app.ek-cashier.com/api/v1/',
});
export const fetchData = async( path, method = 'GET', data = null, lang = 'ar') => {
    try {
        const response = await API({
            method: method,
            url: path,
            data: data,
            headers: {
                'Content-Type': 'multipart/form-data',
                'x-rapidapi-Host': 'asfex.cyb9r.com',
                enctype: 'multipart/form-data',
                Accept: 'application/json',
                'Access-Control-Allow-Origin': '*',
                Locale: lang,
                Authorization: `Bearer ${getCookie('authToken')}`
            }
        });
        if (method === 'POST' || method === 'PUT' || method === 'DELETE'){
            if (response.data.status === true && response.data.message) {
                Swal.fire({
                    icon: 'success',
                    title: 'Success',
                    text: response.data.message,
                    position: 'bottom-end',
                    timer: 5000,
                    timerProgressBar: true,
                    showConfirmButton: false,
                    toast: true
                });
            }
        }        
        return response
    } catch (error) {
        if (method === 'POST' || method === 'PUT' || method === 'DELETE'){
            if (error.response && error.response.data.errors) {
                const errors = error.response.data.errors;
                Object.keys(errors).forEach((key) => {
                    errors[key].forEach((message) => {
                        Swal.fire({
                            icon: 'error',
                            title: 'Error',
                            text: message,
                            position: 'bottom-end',
                            timer: 5000,
                            timerProgressBar: true,
                            showConfirmButton: false,
                            toast: true,
                            didOpen: (toast) => {
                                toast.addEventListener('mouseenter', Swal.stopTimer);
                                toast.addEventListener('mouseleave', Swal.resumeTimer);
                            },
                            
                        });
                    });
                });
            }
        }
    }
    
};