'use client';
import { fetchData } from "@/pages/api/api";
import CustomCheck from "@/components/CustomCheck";
import CustomInput from "@/components/CustomInput";
import CustomSelect from "@/components/CustomSelect";
import Sidebar from "@/components/Sidebar";
import withAuth from "@/utils/withAuth";
import { InputLabel, MenuItem, Select } from "@mui/material";
import { useEffect, useState } from "react"

function CreateAdmin() {
    const [rolesList, setRolesList] = useState([])
    const [formData, setFormData] = useState({
        name: '',
        email: '',
        password: '',
        status: 0,
        role_id: '',
    })
    // Load the data from the server
    const loadData = async () => {
        try {
            const roles = await fetchData('admin/roles-list', 'GET', null, 'ar')
            setRolesList(roles.data.result.roles)
        } catch (error) {

        }
    }
    useEffect(() => { loadData() }, [])

    // Handle the submit
    const handleSubmit = async (e) => {
        e.preventDefault()
        const data = new FormData()
        data.append('name', formData.name)
        data.append('email', formData.email)
        data.append('password', formData.password)
        data.append('status', formData.status)
        data.append('role_id', formData.role_id)
        try {
            const res = await fetchData('admin/store', 'POST', data, 'ar')
        } catch (error) {
            console.log(error)
        }
    }
    return (
        <Sidebar>
            <div className="page-wrapper">
                <div className="head-section d-flex align-items-center justify-content-between mb-2">
                    <h2>
                        إضافة مشرف جديد
                    </h2>
                </div>
                <form action="#"
                    onSubmit={handleSubmit}
                >
                    <div className="d-flex align-items-center justify-content-between mb-4 flex-lg-nowrap flex-wrap gap-3">
                        <CustomInput
                            label='الأسم'
                            type='text'
                            className={'flex-grow-1'}
                            name='name'
                            value={formData.name}
                            onChange={(e) => setFormData({ ...formData, name: e.target.value })}
                        />
                        <CustomInput
                            label='الإيميل'
                            type='email'
                            name='email'
                            className={'flex-grow-1'}
                            value={formData.email}
                            onChange={(e) => setFormData({ ...formData, email: e.target.value })}
                        />
                        <CustomInput
                            label='كلمة المرور'
                            type='password'
                            name='password'
                            className={'flex-grow-1'}
                            value={formData.password}
                            onChange={(e) => setFormData({ ...formData, password: e.target.value })}
                        />
                        <div className="flex-grow-1 mt-3">
                            <InputLabel>
                                الدور
                            </InputLabel>
                            <Select
                                labelId="demo-simple-select-label"
                                id="demo-simple-select"
                                sx={{
                                    width: '100%',
                                    marginBottom: '20px',
                                    borderRadius: '14px',
                                }}
                                value={formData.role_id}
                                onChange={
                                    (e) => setFormData({ ...formData, role_id: e.target.value })
                                }
                            >
                                {
                                    rolesList.length > 0 ? rolesList.map((role, index) => (
                                        <MenuItem key={index} value={role.id}>{role.name}</MenuItem>
                                    ))
                                        :
                                        <MenuItem value={''}>
                                            لا يوجد أدوار
                                        </MenuItem>
                                }
                            </Select>
                        </div>
                        <CustomCheck
                            label='الحالة'
                            name='status'
                            value={formData.status}
                            className={'mt-5'}
                            onChange={(e) => setFormData({
                                ...formData, status:
                                    e.target.checked ? 1 : 0
                            })}
                        />
                    </div>
                    <button className="btn btn-primary">
                        إنشاء
                    </button>
                </form>
            </div>
        </Sidebar>
    )
}
export default withAuth(CreateAdmin);