/* eslint-disable @next/next/no-img-element */
'use client';
import TableCustom from "@/components/TableCustom";
import Link from "next/link";
import { HiOutlinePencilSquare } from "react-icons/hi2";
import { MdDeleteForever } from "react-icons/md";
import { useState, useEffect } from "react";
import { fetchData } from "@/pages/api/api";
import Swal from "sweetalert2";
import icon8 from '@/public/assets/images/icon-8.svg'
import Sidebar from "@/components/Sidebar";
import withAuth from "@/utils/withAuth";


function AdminPage() {
    const [serverData, setServerData] = useState([])
    const [loading, setLoading] = useState(true)
    // Load the data from the server
    const loadData = async () => {
        try {
            const res = await fetchData('admin/list', 'GET', null, 'ar')
            setServerData(res.data.result)
            setLoading(false)
        } catch (error) {
        }
    }
    useEffect(() => {
        loadData()
    }, [])
    if (loading) {
        return (
            <div className="d-flex justify-content-center align-items-center" style={{ height: '100vh' }}>
                <div className="spinner-border text-secondary" role="status">
                    <span className="visually-hidden">Loading...</span>
                </div>
            </div>
        )
    }
    // Delete subscription
    const handleDeleteSup = (id) => async () => {
        try {
            Swal.fire({
                title: 'هل أنت متأكد؟',
                text: "لن تتمكن من التراجع عن هذا الإجراء!",
                icon: 'تحذير',
                showCancelButton: true,
                confirmButtonColor: '#3085d6',
                cancelButtonColor: '#d33',
                confirmButtonText: 'نعم, قم بالحذف!'
            }).then(async (result) => {
                if (result.isConfirmed) {
                    const response = await fetchData(`admin/delete`, 'POST', { id: id }, null)
                    console.log('response', response);
                    if (response.status === true || response.status === 200) {
                        Swal.fire(
                            'تم الحذف!',
                            'تم حذف البيانات بنجاح.',
                            'success'
                        )
                        loadData()
                    }
                }
            }
            )
        } catch (error) {
            console.log('error', error);
        }
    }
    const thead = (
        <tr>
            <th>الأسم</th>
            <th>الإيميل</th>
            <th>دور</th>
            <th className="text-center">الإجراء</th>
        </tr>
    )
    const tbody = (
        serverData?.admins?.map((item, index) => (
            <tr key={index}>
                <td>{item.name}</td>
                <td>{item.email}</td>
                <td>{item.role}</td>
                <td className="text-center">
                    <div className="action d-flex justify-content-center">
                        <Link href={`/dashboard/admin/${item.id}`} className='btn d-flex align-items-center gap-2 edit'>
                            تعديل
                            <HiOutlinePencilSquare />
                        </Link>
                        <button className='btn d-flex align-items-center gap-2 delete'
                            onClick={handleDeleteSup(item.id)}
                        >
                            حذف
                            <MdDeleteForever />
                        </button>
                    </div>
                </td>
            </tr>
        ))

    )

    return (
        <Sidebar>
            <div className="page-wrapper">
                <div className="head-section d-flex align-items-center justify-content-between mb-2">
                    <h2>
                        الميزات
                    </h2>
                    <Link href={`/dashboard/admin/create`} className='btn btn-primary d-flex align-items-center gap-2'>
                        إضافة مشرف جديد
                        <img width={30} height={30} alt='add' src={icon8} className='me-2' />
                    </Link>
                </div>
                <TableCustom thead={thead} tbody={tbody} />
            </div>
        </Sidebar>
    )
}

export default withAuth(AdminPage)