'use client';
import { fetchData } from "@/pages/api/api";
import CustomInput from "@/components/CustomInput";
import Sidebar from "@/components/Sidebar";
import { useState } from "react";
import withAuth from "@/utils/withAuth";
function CreateCountry() {
    const [serverData, setServerData] = useState({
        name_ar: "",
        name_en: "",
        name_tr: "",
    });
    const [loading, setLoading] = useState(true);
    const [error, setError] = useState(null);
    const [cities, setCities] = useState([
        {
            name_en: "",
            name_ar: "",
            name_tr: ""
        }
    ]);
    // Add a new city to the cities array
    const handleNewCity = () => {
        const newCity = {
            name_en: "",
            name_ar: "",
            name_tr: ""
        }
        setCities([...cities, newCity]);
    }
    // Update the city name in the cities array
    const handleCityChange = (e, index) => {
        const { name, value } = e.target;
        const updatedCities = [...cities];
        updatedCities[index][name] = value;
        setCities(updatedCities);
    }
    // Remove the city from the cities array
    const handleDeleteCity = (index) => {
        const updatedCities = [...cities];
        updatedCities.splice(index, 1);
        setCities(updatedCities);
    }
    const handleSubmit = async (e) => {
        e.preventDefault();
        try {
            const response = await fetchData('country/create', 'POST', {
                name_ar: serverData.name_ar,
                name_en: serverData.name_en,
                name_tr: serverData.name_tr,
                cities: cities
            }, null);
        } catch (error) {
        }

    }
    return (
        <Sidebar>
            <div className="page-wrapper">

                <div className="head-section d-flex align-items-center justify-content-between mb-2">
                    <h2>دولة جديدة</h2>
                </div>

                <div className="form-wrapper">
                    <form onSubmit={
                        handleSubmit
                    }>
                        <div className="country d-flex gap-3">
                            <CustomInput
                                name="name_en"
                                id="name_en"
                                type="text"
                                label="الإسم بالإنجليزية"
                                className={'flex-grow-1'}
                                onChange={(e) => setServerData({ ...serverData, name_en: e.target.value })}
                            />
                            <CustomInput
                                name="name_ar"
                                id="name_ar"
                                type="text"
                                label="الإسم بالعربية"
                                className={'flex-grow-1'}
                                onChange={(e) => setServerData({ ...serverData, name_ar: e.target.value })}
                            />
                            <CustomInput
                                name="name_tr"
                                id="name_tr"
                                type="text"
                                label="الإسم بالتركي"
                                className={'flex-grow-1'}
                                onChange={(e) => setServerData({ ...serverData, name_tr: e.target.value })}
                            />
                        </div>
                        <div className="form-group">
                            <h4>المدن</h4>
                            <div className="cities">
                                {
                                    cities.map((city, index) => (
                                        <div key={index} className="city d-flex align-items-center w-100 gap-3">
                                            <CustomInput
                                                name={`name_en`}
                                                type="text"
                                                value={city.name_en}
                                                onChange={(e) => handleCityChange(e, index)}
                                                className={'flex-grow-1'}
                                                label={
                                                    index === 0 ? "الإسم بالإنجليزية" : null
                                                }
                                            />
                                            <CustomInput
                                                name={`name_ar`}
                                                type="text"
                                                value={city.name_ar}
                                                onChange={(e) => handleCityChange(e, index)}
                                                className={'flex-grow-1'}
                                                label={
                                                    index === 0 ? "الإسم بالعربية" : null
                                                }
                                            />
                                            <CustomInput
                                                name={`name_tr`}
                                                type="text"
                                                value={city.name_tr}
                                                onChange={(e) => handleCityChange(e, index)}
                                                className={'flex-grow-1'}
                                                label={
                                                    index === 0 ? "الإسم بالتركي" : null
                                                }
                                            />

                                            <button type="button" className="btn btn-danger mt-4" onClick={() => handleDeleteCity(index)}>حذف</button>
                                        </div>
                                    ))
                                }
                            </div>
                            <button type="button" className="btn btn-primary my-3" onClick={handleNewCity}>إضافة مدينة</button>
                        </div>
                        <button type="submit" className="btn btn-primary">إضافة</button>
                    </form>
                </div>

            </div>
        </Sidebar>
    );
}

export default withAuth(CreateCountry);