/* eslint-disable @next/next/no-img-element */
'use client';
import TableCustom from "@/components/TableCustom";
import { Button } from "react-bootstrap";
import icon8 from '@/public/assets/images/icon-8.svg'
import Link from "next/link";
import { fetchData } from "@/pages/api/api";
import { useState, useEffect } from "react";
import { HiOutlinePencilSquare } from "react-icons/hi2";
import { MdDeleteForever } from "react-icons/md";
import { SlOptions } from "react-icons/sl";
import Swal from 'sweetalert2'
import Sidebar from "@/components/Sidebar";
import withAuth from "@/utils/withAuth";
import Image from "next/image";

function Country() {
    const [serverData, setServerData] = useState([])
    const [loading, setLoading] = useState(true)
    const loadData = async () => {
        const response = await fetchData('country/list', 'GET', null, null)
        setServerData(response.data.result)
        setLoading(false)
    }
    useEffect(() => {
        // fetch data from server
        loadData()
    }
        , [])
    if (loading) {
        return (
            <div className="d-flex justify-content-center align-items-center" style={{ height: '100vh' }}>
                <div className="spinner-border text-secondary" role="status">
                    <span className="visually-hidden">Loading...</span>
                </div>
            </div>
        )
    }
    // Delete country
    const handleDeleteCountry = (id) => async () => {
        try {
            Swal.fire({
                title: 'هل أنت متأكد؟',
                text: "لن تتمكن من التراجع عن هذا الإجراء!",
                icon: 'تحذير',
                showCancelButton: true,
                confirmButtonColor: '#3085d6',
                cancelButtonColor: '#d33',
                confirmButtonText: 'نعم, قم بالحذف!'
            }).then(async (result) => {
                if (result.isConfirmed) {
                    const response = await fetchData(`country/delete`, 'POST', { id: id }, null)
                    if (response.status === true) {
                        Swal.fire(
                            'تم الحذف!',
                            'تم حذف البيانات بنجاح.',
                            'success'
                        )
                        loadData()
                    }
                }
            }
            )

        } catch (error) {
            console.log('error', error);
        }
    }

    const thead = (
        <tr>
            <th>
                الدولة
            </th>
            <th>
                المدن
            </th>
            <th className="text-center">الإجراء</th>
        </tr>
    )
    const tbody = (
        serverData?.countries?.map((item, index) => {
            return (
                <tr key={index}>
                    <td>{item.name_ar}</td>
                    <td>
                        {
                            item.cities.map((city, index) => {
                                return (
                                    <span key={index}>{city.name_ar}   &nbsp;
                                    </span>
                                )
                            })
                        }
                    </td>
                    <td>
                        <div className="action d-flex justify-content-center">
                            <Link href={`/dashboard/country/${item.id}`} className='btn d-flex align-items-center gap-2 edit'>
                                تعديل
                                <HiOutlinePencilSquare />
                            </Link>
                            <button className='btn d-flex align-items-center gap-2 delete'
                                onClick={handleDeleteCountry(item.id)}
                            >
                                حذف
                                <MdDeleteForever />
                            </button>
                        </div>
                    </td>
                </tr>
            )
        }

        )
    )
    return (
        <Sidebar>
            <div className="page-wrapper">
                <div className="head-section d-flex align-items-center justify-content-between mb-2">
                    <h2>
                        الدول
                    </h2>
                    <Link href={`
                    /dashboard/country/create
                    `}
                        className='btn btn-primary d-flex align-items-center gap-2'
                    >
                        إضافة دولة جديدة
                        <Image width={30} height={30} alt='add' src={icon8} className='me-2' />
                    </Link>
                </div>
                <TableCustom thead={thead} tbody={tbody} pagination={serverData?.pagination} />
            </div>
        </Sidebar>
    );
}

export default withAuth(Country)