'use client';
import { fetchData } from "@/pages/api/api";
import CustomInput from "@/components/CustomInput";
import CustomSelect from "@/components/CustomSelect";
import { useEffect, useState } from "react"
import MenuItem from '@mui/material/MenuItem';
import Select from '@mui/material/Select';
import InputLabel from '@mui/material/InputLabel';
import Sidebar from "@/components/Sidebar";
export default function Component({ id }) {
    const [serverData, setServerData] = useState([]);
    const [formData, setFormData] = useState({
        name_ar: '',
        name_en: '',
        name_tr: '',
        sort: '',
        subscriptions: [],
        id: id
    });

    // Load the data from the server
    const loadData = async () => {
        if (!id) return;
        try {
            const res = await fetchData('subscription/list', 'GET', null, 'ar');
            const featureShow = await fetchData(`feature/show?id=${id}`, 'GET', null, 'ar');
            setServerData(res.data.result.subscriptions);
            setFormData({
                name_ar: featureShow.data.result.feature.name_ar,
                name_en: featureShow.data.result.feature.name_en,
                name_tr: featureShow.data.result.feature.name_tr,
                sort: featureShow.data.result.feature.sort,
                subscriptions: featureShow.data.result.feature.subscriptions.map(sub => ({ subscription_id: sub.subscription_id, limit: sub.limit }))
            });
        } catch (error) {
            console.error(error);
        }
    }

    // eslint-disable-next-line react-hooks/exhaustive-deps
    useEffect(() => { loadData(); }, [id]);

    // Handle the change of the select
    const handleChange = (e) => {
        const { value } = e.target;
        const updatedSubscriptions = value.map(id => {
            const existingSubscription = formData.subscriptions.find(sub => sub.subscription_id === id);
            return existingSubscription ? existingSubscription : { subscription_id: id, limit: '' };
        });
        setFormData({
            ...formData,
            subscriptions: updatedSubscriptions
        });
    };

    // Handle the change of the limit
    const handleLimitChange = (index, value) => {
        const updatedSubscriptions = formData.subscriptions.map((sub, i) =>
            i === index ? { ...sub, limit: value } : sub
        );
        setFormData({
            ...formData,
            subscriptions: updatedSubscriptions
        });
    };

    // Get the subscription name
    const getSubscriptionName = (id) => {
        const subscription = serverData.find(item => item.id === id);
        return subscription ? subscription.name_ar : 'الإشتراك غير معروف';
    };

    // Handle the submit
    const handleSubmit = async (e) => {
        e.preventDefault();
        const data = new FormData();
        data.append('name_ar', formData.name_ar);
        data.append('name_en', formData.name_en);
        data.append('name_tr', formData.name_tr);
        data.append('sort', formData.sort);
        data.append('id', id);
        formData.subscriptions.forEach((sub, index) => {
            data.append(`subscriptions[${index}][subscription_id]`, sub.subscription_id);
            data.append(`subscriptions[${index}][limit]`, sub.limit);
        });
        try {
            const res = await fetchData('feature/update', 'POST', data, 'ar');
        } catch (error) {
            console.log(error);
        }
    }

    // Render the component
    return (
        <Sidebar>

        <div className="feature-create page-wrapper">
            <div className="head-section d-flex align-items-center justify-content-between mb-2">
                <h2>تعديل ميزة</h2>
            </div>
            <form action="#" onSubmit={handleSubmit}>
                <div className="d-flex align-items-center justify-content-between mb-4 flex-lg-nowrap flex-wrap gap-3">
                    <CustomInput
                        label='الأسم بالعربي'
                        type='text'
                        name='name_ar'
                        className={'flex-grow-1'}
                        value={formData.name_ar}
                        onChange={(e) => setFormData({ ...formData, name_ar: e.target.value })}
                    />
                    <CustomInput
                        label='الأسم بالإنجليزي'
                        type='text'
                        name='name_en'
                        className={'flex-grow-1'}
                        value={formData.name_en}
                        onChange={(e) => setFormData({ ...formData, name_en: e.target.value })}
                    />
                    <CustomInput
                        label='الأسم بالتركي'
                        type='text'
                        name='name_tr'
                        className={'flex-grow-1'}
                        value={formData.name_tr}
                        onChange={(e) => setFormData({ ...formData, name_tr: e.target.value })}
                    />
                    <CustomInput
                        className={'flex-grow-1'}
                        label='الترتيب'
                        type='number'
                        min='1'
                        name='sort'
                        value={formData.sort}
                        onChange={(e) => setFormData({ ...formData, sort: e.target.value })}
                    />
                </div>

                <InputLabel>الإشتراكات</InputLabel>
                <Select
                    labelId="demo-simple-select-label"
                    id="demo-simple-select"
                    sx={{
                        width: '100%',
                        marginBottom: '20px',
                        borderRadius: '14px',
                    }}
                    multiple={true}
                    value={formData.subscriptions.map(sub => sub.subscription_id)}
                    onChange={handleChange}
                >
                    {serverData.map((item, index) => (
                        <MenuItem key={index} value={item.id}>
                            {item.name_ar}
                        </MenuItem>
                    ))}
                </Select>
                <div className="d-flex flex-wrap gap-3">
                    {formData.subscriptions.map((sub, index) => (
                        <CustomInput
                            key={index}
                            label={`حد ${getSubscriptionName(sub.subscription_id)}`}
                            type='text'
                            name='limit'
                            value={sub.limit}
                            onChange={(e) => handleLimitChange(index, e.target.value)}
                        />
                    ))}
                </div>
                <button className="btn btn-primary mt-4" type="submit">
                    حفظ
                </button>
            </form>
        </div>
        </Sidebar>
    )
}