'use client';
import { fetchData } from "@/pages/api/api";
import CustomInput from "@/components/CustomInput";
import CustomSelect from "@/components/CustomSelect";
import { useEffect, useState } from "react"
import MenuItem from '@mui/material/MenuItem';
import Select from '@mui/material/Select';
import InputLabel from '@mui/material/InputLabel';
import Sidebar from "@/components/Sidebar";
import withAuth from "@/utils/withAuth";


function FeatureCreate() {
    const [serverData, setServerData] = useState([])
    const [formData, setFormData] = useState({
        name_ar: '',
        name_en: '',
        name_tr: '',
        sort: '',
        subscriptions: [],

    })
    // Load the data from the server
    const loadData = async () => {
        try {
            const res = await fetchData('subscription/list', 'GET', null, 'ar')
            setServerData(res.data.result.subscriptions)
        } catch (error) {

        }
    }
    useEffect(() => { loadData() }, [])
    // Handle the change of the select
    const handleChange = (e) => {
        const { value } = e.target;
        const updatedSubscriptions = value.map(id => {
            const existingSubscription = formData.subscriptions.find(sub => sub.subscription_id === id);
            return existingSubscription ? existingSubscription : { subscription_id: id, limt: '' };
        });
        setFormData({
            ...formData,
            subscriptions: updatedSubscriptions
        });
    };
    // Handle the change of the limt
    const handleLimtChange = (index, value) => {
        const updatedSubscriptions = formData.subscriptions.map((sub, i) =>
            i === index ? { ...sub, limt: value } : sub
        );
        setFormData({
            ...formData,
            subscriptions: updatedSubscriptions
        });
    };
    // Get the subscription name
    const getSubscriptionName = (id) => {
        const subscription = serverData.find(item => item.id === id);
        return subscription ? subscription.name_ar : 'Unknown';
    };

    // Handle the submit
    const handleSubmit = async (e) => {
        e.preventDefault()
        const data = new FormData()
        data.append('name_ar', formData.name_ar)
        data.append('name_en', formData.name_en)
        data.append('name_tr', formData.name_tr)
        data.append('sort', formData.sort)
        formData.subscriptions.forEach((sub, index) => {
            data.append(`subscriptions[${index}][subscription_id]`, sub.subscription_id)
            data.append(`subscriptions[${index}][limit]`, sub.limt)
        })
        try {
            const res = await fetchData('feature/store', 'POST', data, 'ar')
        } catch (error) {
            console.log(error)
        }
    }

    // Render the component
    return (
        <Sidebar>

        <div className="feature-create page-wrapper">
            <div className="head-section d-flex align-items-center justify-content-between mb-2">
                <h2>
                    ميزة جديدة
                </h2>
            </div>
            <form action="#"
                onSubmit={handleSubmit}
            >
                <div className="d-flex align-items-center justify-content-between mb-4 flex-lg-nowrap flex-wrap gap-3">
                    <CustomInput
                        label='الأسم بالعربي'
                        type='text'
                        className={'flex-grow-1'}
                        name='name_ar'
                        value={formData.name_ar}
                        onChange={(e) => setFormData({ ...formData, name_ar: e.target.value })}
                    />
                    <CustomInput
                        label='الأسم بالإنجليزي'
                        type='text'
                        name='name_en'
                        className={'flex-grow-1'}
                        value={formData.name_en}
                        onChange={(e) => setFormData({ ...formData, name_en: e.target.value })}
                    />
                    <CustomInput
                        label='الأسم بالتركي'
                        type='text'
                        name='name_tr'
                        className={'flex-grow-1'}
                        value={formData.name_tr}
                        onChange={(e) => setFormData({ ...formData, name_tr: e.target.value })}
                    />
                    <CustomInput
                        className={'flex-grow-1'}
                        label='الترتيب'
                        type='number'
                        name='sort'
                        min='1'
                        value={formData.sort}
                        onChange={(e) => setFormData({ ...formData, sort: e.target.value })}
                    />
                </div>
                <InputLabel>
                    الإشتراكات
                </InputLabel>
                <Select
                    labelId="demo-simple-select-label"
                    id="demo-simple-select"
                    sx={{
                        width: '24%',
                        marginBottom: '20px',
                        borderRadius: '14px',
                    }}
                    multiple={true}
                    value={formData.subscriptions.map(sub => sub.subscription_id)}
                    onChange={handleChange}
                >
                    {serverData.map((item, index) => (
                        <MenuItem key={index} value={item.id}>
                            {item.name_ar}
                        </MenuItem>
                    ))}
                </Select>
                <div
                    className="d-flex flex-wrap gap-3"
                >
                    {formData.subscriptions.map((sub, index) => (
                        <CustomInput
                            key={index}
                            label={`حد ${getSubscriptionName(sub.subscription_id)}`}
                            type='text'
                            name={`subscriptions[${index}][limt]`}
                            value={sub.limt}
                            onChange={(e) => handleLimtChange(index, e.target.value)}
                        />
                    ))}
                </div>
                <button
                    className="btn btn-primary mt-4"
                    type="submit"
                >

                    إنشاء
                </button>
            </form>
        </div>
        </Sidebar>
    )
}

export default withAuth(FeatureCreate)