'use client';
import TableCustom from "@/components/TableCustom";
import Link from "next/link";
import icon8 from '@/public/assets/images/icon-8.svg'
import { MdDeleteForever } from "react-icons/md";
import { HiOutlinePencilSquare } from "react-icons/hi2";
import { useState , useEffect} from "react";
import { fetchData } from "@/pages/api/api";
import Swal from "sweetalert2";
import Sidebar from "@/components/Sidebar";
import withAuth from "@/utils/withAuth";
import Image from "next/image";

function Feature() {
    const [serverData, setServerData] = useState([]);
    const [loading, setLoading] = useState(true);

    // Load the data from the server
    const loadData = async () => {
        try {
            const res = await fetchData('feature/list', 'GET', null, 'ar');
            setServerData(res.data.result);
            setLoading(false);
        } catch (error) {
            console.error(error);
        }
    };

    useEffect(() => {
        loadData();
    }, []);

    if (loading) {
        return (
            <div className="d-flex justify-content-center align-items-center" style={{height: '100vh'}}>
                <div className="spinner-border text-secondary" role="status">
                    <span className="visually-hidden">Loading...</span>
                </div>
            </div>
        );
    }

    // Delete subscription
    const handleDeleteSup = (id) => async () => {
        try {
            Swal.fire({
                title: 'هل أنت متأكد؟',
                text: "لن تتمكن من التراجع عن هذا الإجراء!",
                icon: 'تحذير',
                showCancelButton: true,
                confirmButtonColor: '#3085d6',
                cancelButtonColor: '#d33',
                confirmButtonText: 'نعم, قم بالحذف!'
            }).then(async (result) => {
                if (result.isConfirmed) {
                    const response = await fetchData(`feature/delete`, 'POST', {id: id}, null);
                    if (response.status === true || response.status === 200) {
                        Swal.fire(
                            'تم الحذف!',
                            'تم حذف البيانات بنجاح.',
                            'success'
                        );
                        loadData();
                    }
                }
            });
        } catch (error) {
            console.log('error', error);
        }
    };

    const thead = (
        <tr>
            <th>الأسم</th>
            <th>الإشتراكات</th>
            <th>الترتيب</th>
            <th className="text-center">الإجراء</th>
        </tr>
    );

    const tbody = (
        serverData?.features?.map((item, index) => (
            <tr key={index}>
                <td>{item.name_ar}</td>
                <td>{item.subscriptions.map((sub, index) =>
                    <span key={index}>{sub.name} {
                        index !== item.subscriptions.length - 1 ? ` , ` : ''
                    }</span>
                )}</td>
                <td>{item.sort}</td>
                <td className="text-center">
                    <div className="action d-flex justify-content-center">
                        <Link href={`/dashboard/feature/${item.id}`} className='btn d-flex align-items-center gap-2 edit'>
                            تعديل
                            <HiOutlinePencilSquare />
                        </Link>
                        <button className='btn d-flex align-items-center gap-2 delete' onClick={handleDeleteSup(item.id)}>
                            حذف
                            <MdDeleteForever />
                        </button>
                    </div>
                </td>
            </tr>
        ))
    );

    return (
        <Sidebar>
        <div className="page-wrapper">
            <div className="head-section d-flex align-items-center justify-content-between mb-2">
                <h2>الميزات</h2>
                <Link href={`/dashboard/feature/create`} className='btn btn-primary d-flex align-items-center gap-2'>
                    إضافة ميزة جديدة
                    <Image width={30} height={30} alt='add' src={icon8} className='me-2' />
                </Link>
            </div>
            <TableCustom thead={thead} tbody={tbody} />
        </div>
    </Sidebar>
    );
}

export default withAuth(Feature);
