'use client';
import { fetchData } from "@/pages/api/api";
import CustomCheck from "@/components/CustomCheck";
import CustomInput from "@/components/CustomInput";
import Sidebar from "@/components/Sidebar";
import { useEffect, useState } from "react";
export default function Component({ id }) {
    const [formData, setFormData] = useState({
        name_ar: '',
        name_en: '',
        name_tr: '',
        description_ar: '',
        description_en: '',
        description_tr: '',
        price: '',
        yearly_price: '',
        is_active: 0,
        is_featured: 0,
        sort: '',
        id: id
    })

    // LoadData Function

    async function loadData() {
        if (!id) return
        const response = await fetchData(`subscription/show?id=${id}`, 'GET', null, 'ar');
        setFormData(
            {
                ...formData,
                name_ar: response.data.result.subscription.name_ar || '',
                name_en: response.data.result.subscription.name_en || '',
                name_tr: response.data.result.subscription.name_tr || '',
                description_ar: response.data.result.subscription.description_ar || '',
                description_en: response.data.result.subscription.description_en || '',
                description_tr: response.data.result.subscription.description_tr || '',
                price: response.data.result.subscription.price || '',
                yearly_price: response.data.result.subscription.yearly_price || '',
                is_active: response.data.result.subscription.is_active || 0,
                is_featured: response.data.result.subscription.is_featured || 0,
                sort: response.data.result.subscription.sort || ''
            }
        );
    }
    useEffect(() => {
        loadData();
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [id]);

    // Submit the form
    const handleSubmit = async (e) => {
        e.preventDefault();
        try {
            const response = await fetchData('subscription/update', 'POST', formData, 'ar');
        } catch (error) { }

    }
    return (
        <Sidebar>
            <div className="subscribers page-wrapper">
                <div className="head-section d-flex align-items-center justify-content-between mb-2">
                    <h2>
                        تعديل الإشتراك
                    </h2>
                </div>
                <form action="#" onSubmit={
                    handleSubmit
                }>
                    <div className="d-flex gap-3 mb-2">
                        <CustomInput
                            type="text"
                            name="name_ar"
                            id="name_ar"
                            label="الأسم بالعربي"
                            value={formData.name_ar}
                            onChange={(e) => setFormData({ ...formData, name_ar: e.target.value })}
                            className={'flex-grow-1'}
                        />
                        <CustomInput
                            type="text"
                            name="name_en"
                            id="name_en"
                            label="الأسم بالإنجليزي"
                            value={formData.name_en}
                            onChange={(e) => setFormData({ ...formData, name_en: e.target.value })}
                            className={'flex-grow-1'}
                        />
                        <CustomInput
                            type="text"
                            name="name_tr"
                            id="name_tr"
                            label="الأسم بالتركي"
                            value={formData.name_tr}
                            onChange={(e) => setFormData({ ...formData, name_tr: e.target.value })}
                            className={'flex-grow-1'}
                        />
                    </div>
                    <div className="d-flex gap-3 mb-2">
                        <CustomInput
                            type="text"
                            name="description_ar"
                            id="description_ar"
                            as="textarea"
                            label="الوصف بالعربي"
                            value={formData.description_ar}
                            onChange={(e) => setFormData({ ...formData, description_ar: e.target.value })}
                            className={'flex-grow-1'}
                        />
                        <CustomInput
                            type="text"
                            name="description_en"
                            id="description_en"
                            as="textarea"
                            label="الوصف بالإنجليزي"
                            value={formData.description_en}
                            onChange={(e) => setFormData({ ...formData, description_en: e.target.value })}
                            className={'flex-grow-1'}
                        />
                        <CustomInput
                            type="text"
                            name="description_tr"
                            id="description_tr"
                            as="textarea"
                            label="الوصف بالتركي"
                            value={formData.description_tr}
                            onChange={(e) => setFormData({ ...formData, description_tr: e.target.value })}
                            className={'flex-grow-1'}
                        />
                    </div>

                    <div className="d-flex gap-3 mb-3 align-items-center">
                        <CustomInput
                            type="text"
                            name="price"
                            id="price"
                            label="السعر الشهري"
                            value={formData.price}
                            onChange={(e) => setFormData({ ...formData, price: e.target.value })}
                            className={'flex-grow-1'}
                        />
                        <CustomInput
                            type="text"
                            name="yearly_price"
                            id="yearly_price"
                            label="السعر السنوي"
                            value={formData.yearly_price}
                            onChange={(e) => setFormData({ ...formData, yearly_price: e.target.value })}
                            className={'flex-grow-1'}
                        />
                        <CustomInput
                            type="number"
                            name="sort"
                            id="sort"
                            label="الترتيب"
                            value={formData.sort}
                            onChange={(e) => setFormData({ ...formData, sort: e.target.value })}
                            className={'flex-grow-1'}
                        />
                        <CustomCheck
                            type="checkbox"
                            name="is_active"
                            id="is_active"
                            label="الحالة"
                            checked={formData.is_active === 1}
                            onChange={(e) => setFormData({
                                ...formData, is_active:
                                    e.target.checked ? 1 : 0
                            })}
                            className={'mt-4'}

                        />
                        <CustomCheck
                            type="checkbox"
                            name="is_featured"
                            id="is_featured"
                            label="مميز"
                            checked={formData.is_featured === 1}
                            onChange={(e) => setFormData({
                                ...formData, is_featured:
                                    e.target.checked ? 1 : 0
                            })}
                            className={'mt-4'}
                        />
                    </div>
                    <button type="submit" className="btn btn-primary w-100">
                        حفظ
                    </button>


                </form>
            </div>
        </Sidebar>
    )

}
