/* eslint-disable @next/next/no-img-element */
'use client';
import TableCustom from "@/components/TableCustom";
import Link from "next/link";
import icon8 from '@/public/assets/images/icon-8.svg'
import { fetchData } from "@/pages/api/api";
import { useEffect, useState } from "react";
import { HiOutlinePencilSquare } from "react-icons/hi2";
import { MdDeleteForever } from "react-icons/md";
import Sidebar from "@/components/Sidebar";
import withAuth from "@/utils/withAuth";
import Image from "next/image";
function Subscribers() {
    const [serverData, setServerData] = useState([])
    const [loading, setLoading] = useState(true)
    // Load the data from the server
    const loadData = async () => {
        try {
            const res = await fetchData('subscription/list', 'GET', null, 'ar')
            setServerData(res.data.result)
            setLoading(false)
        } catch (error) {

        }
    }
    useEffect(() => {
        loadData()
    }
        , [])
    if (loading) {
        return (
            <div className="d-flex justify-content-center align-items-center" style={{ height: '100vh' }}>
                <div className="spinner-border text-secondary" role="status">
                    <span className="visually-hidden">Loading...</span>
                </div>
            </div>
        )
    }
    // Delete subscription
    const handleDeleteSup = (id) => async () => {
        try {
            const response = await fetchData(`subscription/delete`, 'POST', { id: id }, null)
            if (response.status === true) {
                loadData()
            }
        } catch (error) {
            console.log('error', error);
        }
    }
    const thead = (
        <tr>
            <th>
                الأسم
            </th>
            <th>
                السعر الشهري
            </th>
            <th>
                السعر السنوي
            </th>
            <th>
                الحالة
            </th>
            <th>
                مميز
            </th>
            <th>
                الترتيب
            </th>
            <th className="text-center">الإجراء</th>
        </tr>
    )
    const tbody = (
        serverData?.subscriptions?.map((item, index) => (
            <tr key={index}>
                <td>{item.name_ar}</td>
                <td>{item.price}</td>
                <td>{item.yearly_price}</td>
                <td>{item.is_active}</td>
                <td>{item.is_featured}</td>
                <td>{item.sort}</td>
                <td className="text-center">
                    <div className="action d-flex justify-content-center">
                        <Link href={`/dashboard/subscribers/${item.id}`} className='btn d-flex align-items-center gap-2 edit'>
                            تعديل
                            <HiOutlinePencilSquare />
                        </Link>
                        <button className='btn d-flex align-items-center gap-2 delete'
                            onClick={handleDeleteSup(item.id)}
                        >
                            حذف
                            <MdDeleteForever />
                        </button>
                    </div>
                </td>
            </tr>
        ))

    )


    return (
        <Sidebar>
            <div className="page-wrapper">
                <div className="head-section d-flex align-items-center justify-content-between mb-2">
                    <h2>
                        المشتركين
                    </h2>
                    <Link href={`
                /dashboard/subscribers/create
                `}
                        className='btn btn-primary d-flex align-items-center gap-2'
                    >
                        إضافة مشترك جديد
                        <Image width={30} height={30} alt='add' src={icon8} className='me-2' />
                    </Link>
                </div>
                <TableCustom thead={thead} tbody={tbody} />
            </div>
        </Sidebar>
    );
}

export default withAuth(Subscribers)