'use client';
import { fetchData } from "@/pages/api/api";
import CustomDate from "@/components/CustomDate";
import CustomInput from "@/components/CustomInput";
import Sidebar from "@/components/Sidebar";
import { InputLabel, MenuItem, Select } from "@mui/material";
import { useEffect, useState } from "react"
import withAuth from "@/utils/withAuth";
function UserCreatePage() {
    const [countries, setCountries] = useState([])
    const [cities, setCities] = useState([])
    const [subscriptions, setSubscriptions] = useState([])
    const [formData, setFormData] = useState({
        name: '',
        email: '',
        company_name: '',
        subdomain: '',
        phone: '',
        employment: '',
        country_id: '',
        city_id: '',
        password: '',
        duration: 'monthly',
        started_at: '',
        subscription_id: '',
    })
    // Load the data from the server
    const loadData = async () => {
        try {
            const countries = await fetchData('country/list', 'GET', null, 'ar')
            setCountries(countries.data.result.countries)
            const subscriptions = await fetchData('subscription/list', 'GET', null, 'ar')
            setSubscriptions(subscriptions.data.result.subscriptions)

        } catch (error) {

        }
    }
    useEffect(() => { loadData() }, [])
    // get the cities of the selected country
    const handleCountryChange = async (e) => {
        const country_id = e.target.value
        setFormData({ ...formData, country_id })
        try {
            const cities = await fetchData(`country/cities?id=${country_id}`, 'GET', null, 'ar')
            setCities(cities.data.result.cities)
        } catch (error) {

        }
    }
    // Handle the change of the select
    const handleSubscriptionChange = (e) => {
        const { value } = e.target;
        setFormData({
            ...formData,
            subscription_id: value
        });
    };

    // Handle the submit
    const handleSubmit = async (e) => {
        e.preventDefault()
        try {
            const res = await fetchData('user/store', 'POST', formData, 'ar')
        } catch (error) {

        }
    }
    return (
        <Sidebar>
            <div className="page-wrapper">
                <div className="head-section d-flex align-items-center justify-content-between mb-2">
                    <h2>
                        إنشاء مستخدم
                    </h2>
                </div>
                <form onSubmit={handleSubmit}>
                    <div className="d-flex align-items-center justify-content-between flex-lg-nowrap flex-wrap gap-3">
                        <CustomInput className={'flex-grow-1'} label="الاسم" name="name" value={formData.name} onChange={(e) => setFormData({ ...formData, name: e.target.value })} />
                        <CustomInput className={'flex-grow-1'} label="البريد الالكتروني" name="email" value={formData.email} onChange={(e) => setFormData({ ...formData, email: e.target.value })} />
                        <CustomInput className={'flex-grow-1'} label="الهاتف" name="phone" value={formData.phone} onChange={(e) => setFormData({ ...formData, phone: e.target.value })} />
                        <CustomInput className={'flex-grow-1'} label="كلمة المرور" name="password" value={formData.password} onChange={(e) => setFormData({ ...formData, password: e.target.value })} />

                    </div>
                    <div className="d-flex align-items-center justify-content-between flex-lg-nowrap flex-wrap gap-3">
                        <CustomInput className={'flex-grow-1 w-25'} label="اسم الشركة" name="company_name" value={formData.company_name} onChange={(e) => setFormData({ ...formData, company_name: e.target.value })} />
                        <CustomInput className={'flex-grow-1 w-25'} label="النطاق" name="subdomain" value={formData.subdomain} onChange={(e) => setFormData({ ...formData, subdomain: e.target.value })} />
                        <CustomInput className={'flex-grow-1 w-25'} label="الوظيفة" name="employment" value={formData.employment} onChange={(e) => setFormData({ ...formData, employment: e.target.value })} />
                        <div className="flex-grow-1 w-25">
                            <InputLabel>

                                المدة
                            </InputLabel>
                            <Select
                                sx={{
                                    width: '100%',
                                    borderRadius: '14px',
                                }}
                                value={formData.duration || 'monthly'}
                                onChange={
                                    (e) => setFormData({
                                        ...formData,
                                        duration: e.target.value
                                    })
                                }
                            >

                                <MenuItem value={'monthly'} selected>monthly</MenuItem>
                                <MenuItem value={'yearly'}>yearly</MenuItem>
                            </Select>
                        </div>
                    </div>
                    <div className="d-flex align-items-center justify-content-between flex-lg-nowrap flex-wrap gap-3">
                        <CustomDate className={'flex-grow-1 w-25'} label="تاريخ البدء" name="started_at" value={formData.started_at} onChange={(e) => setFormData({ ...formData, started_at: e.target.value })} />
                        <div className="flex-grow-1 w-25">
                            <InputLabel>
                                الاشتراك
                            </InputLabel>
                            <Select
                                labelId="demo-simple-select-label"
                                id="demo-simple-select"
                                sx={{
                                    width: '100%',
                                    borderRadius: '14px',
                                }}
                                value={formData.subscription_id || ''}
                                onChange={handleSubscriptionChange}
                            >
                                {subscriptions.map((sub, index) => (
                                    <MenuItem key={index} value={sub.id}>
                                        {sub.name_ar}
                                    </MenuItem>
                                ))}
                            </Select>
                        </div>
                        <div className="flex-grow-1 w-25">
                            <InputLabel>
                                البلد
                            </InputLabel>
                            <Select
                                sx={{
                                    width: '100%',
                                    borderRadius: '14px',
                                }}
                                value={formData.country_id || ''}
                                onChange={handleCountryChange}
                            >
                                {countries.map((country, index) => (
                                    <MenuItem key={index} value={country.id}>
                                        {country.name_ar}
                                    </MenuItem>
                                ))}
                            </Select>
                        </div>
                        <div className="flex-grow-1 w-25">
                            <InputLabel>
                                المدينة
                            </InputLabel>
                            <Select
                                labelId="demo-simple-select-label"
                                id="demo-simple-select"
                                sx={{
                                    width: '100%',
                                    borderRadius: '14px',
                                }}
                                value={formData.city_id || ''}
                                onChange={(e) => setFormData({ ...formData, city_id: e.target.value })}
                            >
                                {cities.map((city, index) => (
                                    <MenuItem key={index} value={city.id}>
                                        {city.name_ar}
                                    </MenuItem>
                                ))}
                            </Select>
                        </div>
                    </div>
                    <button type="submit" className="btn btn-primary mt-3">
                        إنشاء
                    </button>
                </form>
            </div>
        </Sidebar>
    )
}

export default withAuth(UserCreatePage)