// import Image from "next/image";
import { useRouter } from 'next/navigation';
import { useState } from 'react';
import CustomInput from "@/components/CustomInput";
import { setCookie } from 'cookies-next';
import redirectIfAuthenticated from '@/utils/redirectIfAuthenticated';

 function Login() {
  const router = useRouter();
  const [formData, setFormData] = useState({
    email: 'root@gmail.com',
    password: '@#@1234',
  });
  const handleSubmit = async (e) => {
    e.preventDefault();
    try {
      const response = await fetch('https://app.ek-cashier.com/api/v1/login', {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
          'Accept': 'application/json',
          'Access-Control-Allow-Origin': '*',
        },
        body: JSON.stringify(formData)
      });
      const data = await response.json();
      if (data.status === true) {
        // حسب التوكن المستلم من الاستجابة
        const token = data.result.token;
        // تعيين تاريخ انتهاء الكوكي ليوم واحد من الآن
        const expires = new Date();
        expires.setDate(expires.getDate() + 1);
        // تخزين الكوكي الأول
        setCookie('currentUser', true, { expires, path: '/', sameSite: 'strict' });
        // تخزين الكوكي الثاني مع التوكن والانتهاء
        setCookie('authToken', token, { expires, path: '/', sameSite: 'strict' });
        router.push('/dashboard');
      }
    } catch (error) {
      console.error('Error:', error);
    }
  };

  return (
    <div className="login">
      <form onSubmit={handleSubmit} style={{
        minWidth: '600px',
      }}>
        <h2>
          مرحياً بكم في لوحة التحكم Ek-Cashier
        </h2>
        <p>
          الرجاء تسجيل الدخول للمتابعة
        </p>
        <CustomInput
          type="email"
          name="email"
          id="email"
          placeholder="البريد الإلكتروني"
          value={
            formData.email
          }
          onChange={(e) => setFormData({ ...formData, email: e.target.value })}
          className={'flex-grow-1 form-group'}
        />
        <CustomInput
          type="password"
          name="password"
          id="password"
          placeholder="كلمة المرور"
          value={
            formData.password
          }
          onChange={(e) => setFormData({ ...formData, password: e.target.value })}
          className={'flex-grow-1 form-group'}
        />
        <button type="submit" className='btn btn-primary w-100 mt-4'>
          تسجيل الدخول
        </button>
      </form>
    </div>
  );
}

export default redirectIfAuthenticated(Login);
