import axios from 'axios';
import { Cookies } from 'react-cookie';
import { toast } from 'react-toastify';
import Swal from 'sweetalert2';

const cookies = new Cookies();
const token = cookies.get('token');

const apiService = async (url, method, data = null, lang = 'en') => {
  const options = {
    method,
    url: `https://ek-cashier.com/api/v1${url}`,
    headers: {
      'Content-Type': 'multipart/form-data',
      'Accept': 'application/json',
      'Locale': lang,
      'Authorization': token ? `Bearer ${token}` : undefined,
    },
    data: method !== 'GET' ? data : null,
  };

  try {
    const response = await axios(options);
    return response.data;
  } catch (error) {
    // handleHttpErrors(error.response.status, error.response.data);
    throw error;
  }
};

const handleHttpErrors = async (status, errorData) => {
  switch (status) {
    case 401:
      window.location.href = '/';
    case 403:
      window.location.href = '/403';
      break;
    case 404:
      window.location.href = '/404';
      break;
    case 422:
      if (errorData?.errors && errorData.errors.global) {
        for (const [field, messages] of Object.entries(errorData.errors.global)) {
          messages.forEach(message => {
            toast.error(`Validation Error: ${field} - ${message}`);
          });
        }
      } else {
        toast.error(`Validation Error: ${errorData.message || 'Unprocessable Entity'}`);
      }
      break;
    case 480:
      ()=>{
        Swal.fire({
          title: 'Error',
          text: errorData.message,
          icon: 'error',
          confirmButtonText: 'OK',
        }).then((confirm) => {
          if (confirm.isConfirmed) {
            window.location.href = '/dashboard';
          }
        });
      }
      break;
    case 500:
      window.location.href = '/500';
      break;
    case 503:
      window.location.href = '/503';
      break;
    case 405:
      toast.error(`Method Not Allowed: ${errorData.message || 'The method is not allowed for this endpoint.'}`);
      break;
    default:
      console.error('Unhandled HTTP error:', status, errorData);
  }
};

export default apiService;
