/* eslint-disable react/display-name */
// components/redirectIfAuthenticated.js
import { useEffect, useState } from "react";
import { useRouter } from "next/router";
import { getCookie } from 'cookies-next';

const redirectIfAuthenticated = (WrappedComponent) => {
  return (props) => {
    const router = useRouter();
    const token = getCookie('currentUser');

    const [isRedirecting, setIsRedirecting] = useState(false);
    useEffect(() => {
      if (token) {
        setIsRedirecting(true);
        router.push("/dashboard");
      }
    }, []);

    if (isRedirecting) {
      return (
        <div className="loading-screen">
          <span className="loader"></span>
        </div>
      );
    }

    return <WrappedComponent {...props} />;
  };
};

export default redirectIfAuthenticated;
