// hoc/withAuth.js
import { getCookie } from 'cookies-next';
import { useRouter } from 'next/router';
import { useEffect } from 'react';

const withAuth = (WrappedComponent) => {
  const Wrapper = (props) => {
    const router = useRouter();
    const token = getCookie('authToken');

    useEffect(() => {
      if (!token) {
        // Redirect to login page if no token
        router.push('/');
      }
    }, [token, router]);

    // Optionally, you can return a loading state while checking auth
    if (!token) {
      return <p>Loading...</p>;
    }

    return <WrappedComponent {...props} />;
  };

  return Wrapper;
};

export default withAuth;
